==> 0.1.0.tar.gz: lib/API/PIA_API_Page.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework_base/API/PIA_API_Widget.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';


class PIA_API_Page_CallBack
{    Widget API_Page_item(Map<String,dynamic> json) {}

/* example for callback
 return new Padding(padding: EdgeInsets.all(0),
      child: new ListTile(
      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
          onTap: (){
        if(sdata["isclick"] != "1")
          {  sdata["isclick"] = "1"; }
         else
          {  sdata["isclick"] = ""; }

        updatestate(null);
      },
    ));
*/
}

class PIA_API_Page extends StatefulWidget
{  String url;
Map<String,String> post;
PIA_API_Page_CallBack callback;

PIA_API_Page({Key key, this.url,this.post,this.callback}) : super(key: key);

@override
State<StatefulWidget> createState() {
  // TODO: implement createState

  if(post == null)
  { post = Map<String,String>(); }

  return PIA_API_Page_State();
}
}


class PIA_API_Page_State  extends  State<PIA_API_Page> implements PIA_API_CallBack {

  var sdata;

  @override
  Widget build(BuildContext context) {
    print("PIA_API_Page  post:" + widget.post.toString());
    if(sdata == null)
    { return PIA_API_Widget(url: widget.url, post: widget.post, callback: this);}
    else
    { return widget.callback.API_Page_item(sdata); }
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    setState(() {
      sdata = json;
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}

==> 2.0.4.tar.gz: lib/API/PIA_API_Page.dart <==
import 'package:dio/src/dio_error.dart';
import 'package:flutter/material.dart';
import 'package:pia_framework_base/API/PIA_API_Widget.dart';
import 'package:pia_framework_base/Lang/PIA_Lang.dart';
import 'package:pia_framework_base/Variable/PIA_Global.dart';


class PIA_API_Page_CallBack
{    Widget API_Page_item(Map<String,dynamic> json) {}

/* example for callback
 return new Padding(padding: EdgeInsets.all(0),
      child: new ListTile(
      //leading: PIA_Image("Asset/Image/company.png",50,50,0,BoxFit.cover),
      title: new Text(sdata["api"],style:new TextStyle(color: (sdata["isclick"] == "1" ) ? Colors.blue : Colors.pink)),
      subtitle: (sdata["isclick"] == "1") ? PIA_Image("Asset/Image/company.png",150,150,0,BoxFit.cover): null,
          onTap: (){
        if(sdata["isclick"] != "1")
          {  sdata["isclick"] = "1"; }
         else
          {  sdata["isclick"] = ""; }

        updatestate(null);
      },
    ));
*/
}

class PIA_API_Page extends StatefulWidget
{  String url;
   Map<String,String> post;
   PIA_API_Page_CallBack callback;
   bool reset;
   PIA_API_Page({Key key, this.url,this.post,this.callback, this.reset}) : super(key: key);

@override
State<StatefulWidget> createState() {
  // TODO: implement createState

  if(post == null)
  { post = Map<String,String>(); }

  return PIA_API_Page_State();
}
}


class PIA_API_Page_State  extends  State<PIA_API_Page> implements PIA_API_CallBack {

  var sdata;

  void initState() {
    print("PIA_API_Page_State init");
    super.initState();
  }


  @override
  void dispose() {
    super.dispose();
    print("PIA_API_Page_State dispose");
  }

  @override
  void deactivate() {
    super.deactivate();
    print("PIA_API_Page_State deactivate");
  }

  @override
  void didChangeDependencies() {
    print("PIA_API_Page_State didChangeDependencies ");
  }

  @override
  void didChangeAppLifecycleState(AppLifecycleState state) {
    print("PIA_API_Page_State didChangeDependencie:" + state.toString());

  }

  @override
  Widget build(BuildContext context) {
    print("Build PIA_API_Page  post:" + widget.post.toString() + ", reset ${widget.reset}");
    if(sdata == null || widget.reset == true)
    { return PIA_API_Widget(url: widget.url, post: widget.post, callback: this);}
    else
    { return widget.callback.API_Page_item(sdata); }
  }

  @override
  void API_Error(DioErrorType error) {
    // TODO: implement API_Error
  }

  @override
  void API_Success(Map<String, dynamic> json, List j) {
    setState(() {
      widget.reset = false;
      sdata = json;
    });
  }

  @override
  void API_Upload_prodcess(int upload, int total) {
    // TODO: implement API_Upload_prodcess
  }

}
